Content Scramble System (CSS)
-----------------------------

Many DVDs use CSS[0] as a form of a Digital Rights Management (DRM) to encrypt
the content of Video DVDs. To play such discs a special library is needed to
decode them, libdvdcss.

Due to the legal limbo of libdvdcss in some particular juristictions, some
distributions including Debian do not distribute libdvdcss.

If it is legal for you to use CSS in your juristiction, you can:

  * Manually download and compile the source code from
    <http://www.videolan.org/developers/libdvdcss.html>.

  * Use packages from derivatives that include libdvdcss.

 [0] <http://en.wikipedia.org/wiki/Content_Scramble_System>

 -- Daniel Baumann <mail@daniel-baumann.ch>  Fri, 02 Oct 2009 16:10:06 +0200
